@@ -140,7 +140,14 @@ class AssignmentOptions:
         if isinstance(principal, dict):
             principal = PrincipalProperty(**principal)
         if __debug__:
-            type_hints = typing.get_type_hints(AssignmentOptions.__init__)
+            def stub(
+                *,
+                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                target_id: builtins.str,
+                target_type: typing.Optional["TargetTypes"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
             check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
@@ -215,7 +222,15 @@ class AssignmentProps(AssignmentOptions):
         if isinstance(principal, dict):
             principal = PrincipalProperty(**principal)
         if __debug__:
-            type_hints = typing.get_type_hints(AssignmentProps.__init__)
+            def stub(
+                *,
+                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                target_id: builtins.str,
+                target_type: typing.Optional["TargetTypes"] = None,
+                permission_set: "IPermissionSet",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
             check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
@@ -291,7 +306,13 @@ class CustomerManagedPolicyReference(
         :param path: ``CfnPermissionSet.CustomerManagedPolicyReferenceProperty.Path``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CustomerManagedPolicyReference.__init__)
+            def stub(
+                *,
+                name: builtins.str,
+                path: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -439,7 +460,15 @@ class _IPermissionSetProxy(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IPermissionSet.grant)
+            def stub(
+                id: builtins.str,
+                *,
+                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                target_id: builtins.str,
+                target_type: typing.Optional["TargetTypes"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         assignment_options = AssignmentOptions(
             principal=principal, target_id=target_id, target_type=target_type
@@ -471,7 +500,13 @@ class PermissionBoundary(aws_cdk.aws_sso.CfnPermissionSet.PermissionsBoundaryPro
         :param managed_policy_arn: ``CfnPermissionSet.PermissionsBoundaryProperty.ManagedPolicyArn``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionBoundary.__init__)
+            def stub(
+                *,
+                customer_managed_policy_reference: typing.Optional[typing.Union[typing.Union[aws_cdk.aws_sso.CfnPermissionSet.CustomerManagedPolicyReferenceProperty, typing.Dict[str, typing.Any]], aws_cdk.IResolvable]] = None,
+                managed_policy_arn: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument customer_managed_policy_reference", value=customer_managed_policy_reference, expected_type=type_hints["customer_managed_policy_reference"])
             check_type(argname="argument managed_policy_arn", value=managed_policy_arn, expected_type=type_hints["managed_policy_arn"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -547,7 +582,22 @@ class PermissionSet(
         :param session_duration: The length of time that the application user sessions are valid for.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionSet.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                name: builtins.str,
+                sso_instance_arn: builtins.str,
+                aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
+                customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
+                description: typing.Optional[builtins.str] = None,
+                inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
+                permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
+                relay_state_type: typing.Optional[builtins.str] = None,
+                session_duration: typing.Optional[aws_cdk.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PermissionSetProps(
@@ -579,7 +629,13 @@ class PermissionSet(
         :param permission_set_arn: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionSet.from_permission_set_arn)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                permission_set_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument permission_set_arn", value=permission_set_arn, expected_type=type_hints["permission_set_arn"])
@@ -602,7 +658,15 @@ class PermissionSet(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionSet.grant)
+            def stub(
+                id: builtins.str,
+                *,
+                principal: typing.Union["PrincipalProperty", typing.Dict[str, typing.Any]],
+                target_id: builtins.str,
+                target_type: typing.Optional["TargetTypes"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         assignment_options = AssignmentOptions(
             principal=principal, target_id=target_id, target_type=target_type
@@ -650,7 +714,13 @@ class PermissionSetAttributes:
         :param sso_instance_arn: The SSO instance ARN of the permission set.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionSetAttributes.__init__)
+            def stub(
+                *,
+                permission_set_arn: builtins.str,
+                sso_instance_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument permission_set_arn", value=permission_set_arn, expected_type=type_hints["permission_set_arn"])
             check_type(argname="argument sso_instance_arn", value=sso_instance_arn, expected_type=type_hints["sso_instance_arn"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -732,7 +802,20 @@ class PermissionSetProps:
         if isinstance(permissions_boundary, dict):
             permissions_boundary = PermissionBoundary(**permissions_boundary)
         if __debug__:
-            type_hints = typing.get_type_hints(PermissionSetProps.__init__)
+            def stub(
+                *,
+                name: builtins.str,
+                sso_instance_arn: builtins.str,
+                aws_managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
+                customer_managed_policy_references: typing.Optional[typing.Sequence[typing.Union[CustomerManagedPolicyReference, typing.Dict[str, typing.Any]]]] = None,
+                description: typing.Optional[builtins.str] = None,
+                inline_policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument] = None,
+                permissions_boundary: typing.Optional[typing.Union[PermissionBoundary, typing.Dict[str, typing.Any]]] = None,
+                relay_state_type: typing.Optional[builtins.str] = None,
+                session_duration: typing.Optional[aws_cdk.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument sso_instance_arn", value=sso_instance_arn, expected_type=type_hints["sso_instance_arn"])
             check_type(argname="argument aws_managed_policies", value=aws_managed_policies, expected_type=type_hints["aws_managed_policies"])
@@ -895,7 +978,13 @@ class PrincipalProperty:
         :param principal_type: The type of the principal.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PrincipalProperty.__init__)
+            def stub(
+                *,
+                principal_id: builtins.str,
+                principal_type: "PrincipalTypes",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument principal_id", value=principal_id, expected_type=type_hints["principal_id"])
             check_type(argname="argument principal_type", value=principal_type, expected_type=type_hints["principal_type"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -970,7 +1059,17 @@ class Assignment(
         :param target_type: The entity type for which the assignment will be created. Default: TargetTypes.AWS_ACCOUNT
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Assignment.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                permission_set: IPermissionSet,
+                principal: typing.Union[PrincipalProperty, typing.Dict[str, typing.Any]],
+                target_id: builtins.str,
+                target_type: typing.Optional[TargetTypes] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AssignmentProps(
